==> python_quant-0.1.7.tar.gz: python_quant-0.1.7/src/python_quant/mode_handler/option/risk_mode_option_handler.py <==
from typing import Dict, Any
from datetime import datetime
from logging import Logger
from python_quant.instrument.option import Option

def risk_mode_option_handler(
    instrument: Dict[str, Any],
    as_of_date: datetime,
    market_data: Dict[str, Any],
    logger: Logger,
):  
    underlying = instrument["underlying"]
    option = Option(
        strike_price=float(instrument["strike"]),
        expiration_date= datetime.strptime(
            instrument["expiry"], "%Y%m%d"
        ),
        market_price=instrument.get("market_price", None),
        volatility=float(market_data[underlying["symbol"]].get("volatility")),
        underlying_ticker=underlying["symbol"],
        underlying_type=underlying["type"],
        call_put=Option.CallPut.CALL
        if instrument["option_type"].upper() == "CALL"
        else Option.CallPut.PUT,
        option_type=Option.OptionType.EUROPEAN
    )
    style = instrument.get("style") or ""



    match style.upper():
        case "EUROPEAN":
            logger.info("Processing EUROPEAN option in RISK mode.")
            logger.info(f"Using BSM Pricer for option: {option}")
            from python_quant.pricers.bsm_pricer import BSMPricer
            pricer = BSMPricer(
                instrument=option,
                as_of_date=as_of_date,
                market_data=market_data,
                logger=logger
            )
            return pricer.greeks()
            
        case _:
            raise NotImplementedError(
                f"RISK mode not implemented for option style: {style}"
            )

==> python_quant-0.1.9.tar.gz: python_quant-0.1.9/src/python_quant/mode_handler/option/risk_mode_option_handler.py <==
from typing import Dict, Any
from datetime import datetime
from logging import Logger
from python_quant.instrument.option import Option
from python_quant.pricers.bsm_pricer import BSMPricer


def risk_mode_option_handler(
    instrument: Dict[str, Any],
    as_of_date: datetime,
    market_data: Dict[str, Any],
    logger: Logger,
) -> tuple[Dict[str, Any], Dict[str, Any]]:
    underlying = instrument["underlying"]
    option = Option(
        strike_price=float(instrument["strike"]),
        expiration_date=datetime.strptime(instrument["expiry"], "%Y%m%d"),
        market_price=instrument.get("market_price", None),
        volatility=float(market_data[underlying["symbol"]].get("volatility")),
        underlying_ticker=underlying["symbol"],
        underlying_type=underlying["type"],
        call_put=Option.CallPut.CALL
        if instrument["option_type"].upper() == "CALL"
        else Option.CallPut.PUT,
        option_type=Option.OptionType.EUROPEAN,
    )
    style = instrument.get("style") or ""

    match style.upper():
        case "EUROPEAN":
            logger.info("Processing EUROPEAN option in RISK mode.")
            logger.info(f"Using BSM Pricer for option: {option}")
            pricer = BSMPricer(
                instrument=option,
                as_of_date=as_of_date,
                market_data=market_data,
                logger=logger,
            )
            return option.to_dict(), pricer.greeks()

        case _:
            raise NotImplementedError(
                f"RISK mode not implemented for option style: {style}"
            )
